@@ -148,6 +148,7 @@ pub struct CompileWarning {
     pub warning_content: Warning,
 }
 
+#[derive(Clone, Copy)]
 pub struct LineCol {
     pub line: usize,
     pub col: usize,
@@ -788,8 +789,16 @@ pub enum CompileError {
     ContractStorageFromExternalContext { span: Span },
     #[error("Array index out of bounds; the length is {count} but the index is {index}.")]
     ArrayOutOfBounds { index: u64, count: u64, span: Span },
+    #[error("Tuple index out of bounds; the arity is {count} but the index is {index}.")]
+    TupleOutOfBounds {
+        index: usize,
+        count: usize,
+        span: Span,
+    },
     #[error("The name \"{name}\" shadows another symbol with the same name.")]
     ShadowsOtherSymbol { name: String, span: Span },
+    #[error("The name \"{name}\" imported through `*` shadows another symbol with the same name.")]
+    StarImportShadowsOtherSymbol { name: String, span: Span },
     #[error(
         "Match expression arm has mismatched types.\n\
          expected: {expected}\n\
@@ -806,6 +815,8 @@ pub enum CompileError {
     IntegerTooSmall { span: Span, ty: String },
     #[error("Literal value contains digits which are not valid for type {ty}.")]
     IntegerContainsInvalidDigit { span: Span, ty: String },
+    #[error("Unexpected alias after an asterisk in an import statement.")]
+    AsteriskWithAlias { span: Span },
 }
 
 impl std::convert::From<TypeError> for CompileError {
@@ -995,7 +1006,9 @@ impl CompileError {
             BurnFromExternalContext { span, .. } => span,
             ContractStorageFromExternalContext { span, .. } => span,
             ArrayOutOfBounds { span, .. } => span,
+            TupleOutOfBounds { span, .. } => span,
             ShadowsOtherSymbol { span, .. } => span,
+            StarImportShadowsOtherSymbol { span, .. } => span,
             MatchWrongType { span, .. } => span,
             NotAnEnum { span, .. } => span,
             PatternMatchingAlgorithmFailure(_, span) => span,
@@ -1004,6 +1017,7 @@ impl CompileError {
             IntegerTooLarge { span, .. } => span,
             IntegerTooSmall { span, .. } => span,
             IntegerContainsInvalidDigit { span, .. } => span,
+            AsteriskWithAlias { span, .. } => span,
         }
     }
 
