@@ -32,19 +32,22 @@ impl CodeBlock {
         let block_inner = block.into_inner();
         let mut contents = Vec::new();
         for pair in block_inner {
-            contents.push(match pair.as_rule() {
-                Rule::declaration => AstNode {
-                    content: AstNodeContent::Declaration(check!(
-                        Declaration::parse_from_pair(pair.clone(), config),
-                        continue,
-                        warnings,
-                        errors
-                    )),
+            let mut ast_nodes = match pair.as_rule() {
+                Rule::declaration => check!(
+                    Declaration::parse_from_pair(pair.clone(), config),
+                    continue,
+                    warnings,
+                    errors
+                )
+                .into_iter()
+                .map(|content| AstNode {
+                    content: AstNodeContent::Declaration(content),
                     span: span::Span {
                         span: pair.as_span(),
                         path: path.clone(),
                     },
-                },
+                })
+                .collect::<Vec<_>>(),
                 Rule::expr_statement => {
                     let evaluated_node = check!(
                         Expression::parse_from_pair(
@@ -55,13 +58,13 @@ impl CodeBlock {
                         warnings,
                         errors
                     );
-                    AstNode {
+                    vec![AstNode {
                         content: AstNodeContent::Expression(evaluated_node),
                         span: span::Span {
                             span: pair.as_span(),
                             path: path.clone(),
                         },
-                    }
+                    }]
                 }
                 Rule::return_statement => {
                     let evaluated_node = check!(
@@ -70,13 +73,13 @@ impl CodeBlock {
                         warnings,
                         errors
                     );
-                    AstNode {
+                    vec![AstNode {
                         content: AstNodeContent::ReturnStatement(evaluated_node),
                         span: span::Span {
                             span: pair.as_span(),
                             path: path.clone(),
                         },
-                    }
+                    }]
                 }
                 Rule::expr => {
                     let res = check!(
@@ -85,10 +88,10 @@ impl CodeBlock {
                         warnings,
                         errors
                     );
-                    AstNode {
+                    vec![AstNode {
                         content: AstNodeContent::ImplicitReturnExpression(res.clone()),
                         span: res.span(),
-                    }
+                    }]
                 }
                 Rule::while_loop => {
                     let res = check!(
@@ -97,13 +100,13 @@ impl CodeBlock {
                         warnings,
                         errors
                     );
-                    AstNode {
+                    vec![AstNode {
                         content: AstNodeContent::WhileLoop(res),
                         span: span::Span {
                             span: pair.as_span(),
                             path: path.clone(),
                         },
-                    }
+                    }]
                 }
                 a => {
                     println!("In code block parsing: {:?} {:?}", a, pair.as_str());
@@ -116,7 +119,8 @@ impl CodeBlock {
                     ));
                     continue;
                 }
-            })
+            };
+            contents.append(&mut ast_nodes);
         }
 
         ok(
