@@ -181,6 +181,9 @@ impl TypedAstNode {
                     };
                     let mut res = match a.import_type {
                         ImportType::Star => namespace.star_import(from_module, a.call_path),
+                        ImportType::SelfImport => {
+                            namespace.self_import(from_module, a.call_path, a.alias)
+                        }
                         ImportType::Item(s) => {
                             namespace.item_import(from_module, a.call_path, &s, a.alias)
                         }
@@ -251,6 +254,7 @@ impl TypedAstNode {
                                     name: name.clone(),
                                     body,
                                     is_mutable: is_mutable.into(),
+                                    const_decl_origin: false,
                                     type_ascription,
                                 });
                             namespace.insert(name, typed_var_decl.clone());
@@ -283,6 +287,7 @@ impl TypedAstNode {
                                     } else {
                                         VariableMutability::Immutable
                                     },
+                                    const_decl_origin: true,
                                     type_ascription: insert_type(type_ascription),
                                 });
                             namespace.insert(name, typed_const_decl.clone());
@@ -790,6 +795,7 @@ fn import_new_file(
     };
     dep_config.file_name = file_name;
     dep_config.dir_of_code = Arc::new(dep_path);
+    let dep_namespace = create_new_scope(namespace);
     let crate::InnerDependencyCompileResult {
         name,
         namespace: module,
@@ -797,7 +803,7 @@ fn import_new_file(
     } = check!(
         crate::compile_inner_dependency(
             file_as_string,
-            namespace,
+            dep_namespace,
             dep_config,
             dead_code_graph,
             dependency_graph
@@ -1122,6 +1128,7 @@ fn type_check_trait_methods(
                         },
                         // TODO allow mutable function params?
                         is_mutable: VariableMutability::Immutable,
+                        const_decl_origin: false,
                         type_ascription: r#type,
                     }),
                 );
